/************************************************************************/
/*				                        		*/
/*	  DACSPI2DemoProject 		                                */
/*						                  	*/
/*					                        	*/
/************************************************************************/
/*	Author: Cristian Fatu						*/
/*	Copyright 2012, Digilent Inc.					*/
/************************************************************************/
/*  File Description: 			             		        */
/*					                        	*/
/* This file implements a simple demo application that demonstrates     */
/* how to use the DACSPI2 library.				        */
/*									*/
/*	Functionality:							*/
/*									*/
/* In the setup() function, the application initializes                 */
/* the DACSPI2 library object.                                          */
/* In the loop() function, the application repeatedly increases and     */
/* decreases the physical value to be reconstructed by the DA converter.*/
/*					                        	*/
/*	Required Hardware:						*/
/*	  1. Cerebot MX4cK    					        */
/*	  2. PmodDA2 - plugged into JB connector (SPI0 interface)	*/
/************************************************************************/
/*  Revision History:			        			*/
/*					                        	*/
/*	01/12/2012(CristianF): created	       			        */
/*						                     	*/
/************************************************************************/

/* -------------------------------------------------------------------- */
/*				Include File Definitions  	        */
/* -------------------------------------------------------------------- */
#include <DACSPI2.h>

#include <DSPI.h>  // DSPI library header must be included in the sketch
/* -------------------------------------------------------------------- */
/*				Global Variables		        */
/* -------------------------------------------------------------------- */
  DACSPI2 myDACSPI2; // the library object
  float dMaxValue = 3.3;
  float dMinValue = 0;
  float dStep = 0.05;
  float dValue;

/* -------------------------------------------------------------------- */
/*	               Procedure Definitions	                        */
/* -------------------------------------------------------------------- */
/***	setup
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		 Performs basic initialization.		
/*** ---------------------------------------------------------- ***/
void setup()
{ 
  // initialize PmodDACSPI2 on SPI
  myDACSPI2.begin(PAR_ACCESS_SPI0); // corresponds to DSPI0 - connector JB
//  myDACSPI2.begin(PAR_ACCESS_SPI1); // corresponds to DSPI1 - connector J1
}

/*** ---------------------------------------------------------- ***/
/***	loop
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Main program module. Enters the main program loop.
/*** ---------------------------------------------------------- ***/
void loop()
{ 
  // increase physical value from minimum to maximum value 
  for(dValue = dMinValue; dValue <= dMaxValue; dValue += dStep)
  {
    // send value to the DA converter
    myDACSPI2.WritePhysicalValue(dValue);
    // wait some time
    delay(200);
  }


  // decrease physical value from maximum to minimum value
  for(dValue = dMaxValue; dValue >= dMinValue; dValue -= dStep)
  {
    // send value to the DA converter
    myDACSPI2.WritePhysicalValue(dValue);
    // wait some time
    delay(200);
  }
}
